@@ -137,6 +137,7 @@ from ._jsii import *
 import aws_cdk.aws_codepipeline
 import aws_cdk.aws_ec2
 import aws_cdk.aws_imagebuilder
+import aws_cdk.aws_kms
 import aws_cdk.aws_sns
 import aws_cdk.core
 
@@ -155,9 +156,9 @@ class AmiPipelineLib(
         pipeline_config: typing.Any,
         component_deps_config: typing.Sequence[typing.Any],
         *,
-        channel: builtins.str,
-        slack_webhook_url: builtins.str,
-        username: builtins.str,
+        channel: typing.Optional[builtins.str] = None,
+        slack_webhook_url: typing.Optional[builtins.str] = None,
+        username: typing.Optional[builtins.str] = None,
     ) -> None:
         '''Constructor.
 
@@ -293,6 +294,15 @@ class AmiPipelineLib(
     ) -> None:
         jsii.set(self, "distributionConfig", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="ebsEncryptionKey")
+    def ebs_encryption_key(self) -> typing.Optional[aws_cdk.aws_kms.Key]:
+        return typing.cast(typing.Optional[aws_cdk.aws_kms.Key], jsii.get(self, "ebsEncryptionKey"))
+
+    @ebs_encryption_key.setter
+    def ebs_encryption_key(self, value: typing.Optional[aws_cdk.aws_kms.Key]) -> None:
+        jsii.set(self, "ebsEncryptionKey", value)
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="imagePipeline")
     def image_pipeline(
@@ -635,38 +645,37 @@ class SlackConfiguration:
     def __init__(
         self,
         *,
-        channel: builtins.str,
-        slack_webhook_url: builtins.str,
-        username: builtins.str,
+        channel: typing.Optional[builtins.str] = None,
+        slack_webhook_url: typing.Optional[builtins.str] = None,
+        username: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
         :param channel: 
         :param slack_webhook_url: 
         :param username: 
         '''
-        self._values: typing.Dict[str, typing.Any] = {
-            "channel": channel,
-            "slack_webhook_url": slack_webhook_url,
-            "username": username,
-        }
+        self._values: typing.Dict[str, typing.Any] = {}
+        if channel is not None:
+            self._values["channel"] = channel
+        if slack_webhook_url is not None:
+            self._values["slack_webhook_url"] = slack_webhook_url
+        if username is not None:
+            self._values["username"] = username
 
     @builtins.property
-    def channel(self) -> builtins.str:
+    def channel(self) -> typing.Optional[builtins.str]:
         result = self._values.get("channel")
-        assert result is not None, "Required property 'channel' is missing"
-        return typing.cast(builtins.str, result)
+        return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def slack_webhook_url(self) -> builtins.str:
+    def slack_webhook_url(self) -> typing.Optional[builtins.str]:
         result = self._values.get("slack_webhook_url")
-        assert result is not None, "Required property 'slack_webhook_url' is missing"
-        return typing.cast(builtins.str, result)
+        return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def username(self) -> builtins.str:
+    def username(self) -> typing.Optional[builtins.str]:
         result = self._values.get("username")
-        assert result is not None, "Required property 'username' is missing"
-        return typing.cast(builtins.str, result)
+        return typing.cast(typing.Optional[builtins.str], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
